@@ -1,7 +1,7 @@
 
 /* png.c - location for general purpose libpng functions
  *
- * libpng version 1.0.5s - February 18, 2000
+ * libpng version 1.0.6a - March 23, 2000
  * Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.
  * Copyright (c) 1996, 1997 Andreas Dilger
  * Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson
@@ -13,13 +13,15 @@
 #include <assert.h>
 #include "png.h"
 
+/* Generate a compiler error if there is an old png.h in the search path. */
+typedef version_1_0_6a Your_png_h_is_not_version_1_0_6a;
+
 /* Version information for C files.  This had better match the version
- * string defined in png.h.
- */
+ * string defined in png.h.  */
 
 #ifdef PNG_USE_GLOBAL_ARRAYS
 /* png_libpng_ver was changed to a function in version 1.0.5c */
-char png_libpng_ver[12] = "1.0.5s";
+char png_libpng_ver[12] = "1.0.6a";
 
 /* png_sig was changed to a function in version 1.0.5c */
 /* Place to hold the signature string for a PNG file. */
@@ -543,7 +545,7 @@ png_charp
 png_get_copyright(png_structp png_ptr)
 {
    if (png_ptr != NULL || png_ptr == NULL)  /* silence compiler warning */
-   return ("\n libpng version 1.0.5s - February 18, 2000\n\
+   return ("\n libpng version 1.0.6a - March 23, 2000\n\
    Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.\n\
    Copyright (c) 1996, 1997 Andreas Dilger\n\
    Copyright (c) 1998, 1999, 2000 Glenn Randers-Pehrson\n");
@@ -561,8 +563,8 @@ png_get_libpng_ver(png_structp png_ptr)
 {
    /* Version of *.c files used when building libpng */
    if(png_ptr != NULL) /* silence compiler warning about unused png_ptr */
-      return("1.0.5s");
-   return("1.0.5s");
+      return("1.0.6a");
+   return("1.0.6a");
 }
 
 png_charp
@@ -583,15 +585,6 @@ png_get_header_version(png_structp png_ptr)
    return(PNG_HEADER_VERSION_STRING);
 }
 
-/* Generate a compiler error if there is an old png.h in the search path. */
-void
-png_check_version
-   (version_1_0_5s png_h_is_not_version_1_0_5s)
-{
-   if(png_h_is_not_version_1_0_5s == NULL)
-     return;
-}
-
 #ifdef PNG_HANDLE_AS_UNKNOWN_SUPPORTED
 int
 png_handle_as_unknown(png_structp png_ptr, png_bytep chunk_name)
